/**
 * lcd-clock by peter dannegger
 *
 * via shift register 74HC164
 */
#include <inttypes.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#define PLACE_GLOBALS_HERE
#include "config.h"
#include "lcd.h"
#include "clock.h"


static uint16_t timer;


static void init(void) {
   DDR_COMM_CLOCK |= 1 << PIN_COMM_CLOCK;
   DDR_COMM_DATA  |= 1 << PIN_COMM_DATA;
   DDR_COMM_SYNC  |= 1 << PIN_COMM_SYNC;

   /*
    * timer 1 is a 16bit timer in ctc-mode with a calculated
    * upper limit depending on the avr system clock
    */
   TCCR1A = 0;
   TCCR1B = 1 << WGM12 | 1 << CS00;                        // CTC-mode, no prescale
#ifdef __AVR_ATmega88__   
   TIMSK0 |= 1 << OCIE1A;
#endif   
#ifdef __AVR_ATtiny2313__
   TIMSK  |= 1 << OCIE1A; 
#endif   
   OCR1A  = TIMER_TL;
   
   lcdInit();

   time.day   = 17;
   time.month = 6;
   time.year  = 8;

   sei();
}


/*
 * a-channel of the 16-bit timer is used for time related tasks
 * see clock.h for calculations
 */
ISR(TIMER1_COMPA_vect) {
   if (!(++timer % TIMER_IPS)) {
      timer  = 0;
      F_1sec = 1;
   }
}


void main(void) {
   init();

   for (;;) {
      if (F_1sec) {
         F_1sec = 0;
         clock();
         displayClock();
      }
   }
}
